@@ -1,10 +1,10 @@
-# @(#)$Id: SRLock.pm 147 2010-09-22 01:43:20Z pjf $
+# @(#)$Id: SRLock.pm 150 2010-09-22 18:44:19Z pjf $
 
 package IPC::SRLock;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 147 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 150 $ =~ /\d+/gmx );
 use parent qw(Class::Accessor::Fast);
 
 use Class::MOP;
@@ -13,7 +13,7 @@ use Date::Format;
 use English qw(-no_match_vars);
 use IPC::SRLock::ExceptionClass;
 use Time::Elapsed qw(elapsed);
-use TryCatch;
+use Try::Tiny;
 
 my %ATTRS = ( debug    => 0,
               log      => undef,
@@ -30,12 +30,12 @@ sub new {
    my ($self, @rest) = @_;
 
    my $args  = $self->_arg_list( @rest );
-   my $attrs = $self->_hash_merge( \%ATTRS, $args );
+   my $attrs = __hash_merge( \%ATTRS, $args );
    my $class = __PACKAGE__.q(::).(ucfirst $attrs->{type});
 
    $self->_ensure_class_loaded( $class ); # Load factory subclass
 
-   my $new   = bless $attrs, $class;
+   my $new = bless $attrs, $class;
 
    $new->log  ( $new->log || Class::Null->new() );
    $new->pid  ( $PID );
@@ -43,10 +43,6 @@ sub new {
    return $new;
 }
 
-sub catch {
-   my ($self, @rest) = @_; return IPC::SRLock::ExceptionClass->catch( @rest );
-}
-
 sub get_table {
    my $self  = shift;
    my $count = 0;
@@ -64,11 +60,14 @@ sub get_table {
                  values => [] };
 
    for my $lock (@{ $self->list }) {
-      my $flds       = {};
+      my $flds = {};
+
       $flds->{id   } = $lock->{key};
       $flds->{pid  } = $lock->{pid};
       $flds->{stime} = time2str( q(%Y-%m-%d %H:%M:%S), $lock->{stime} );
-      my $tleft      = $lock->{stime} + $lock->{timeout} - time;
+
+      my $tleft = $lock->{stime} + $lock->{timeout} - time;
+
       $flds->{tleft} = $tleft > 0 ? elapsed( $tleft ) : 'Expired';
       $flds->{class}->{tleft}
                      = $tleft < 1 ? q(error dataValue) : q(odd dataValue);
@@ -87,7 +86,7 @@ sub list {
 sub reset {
    my ($self, @rest) = @_; my $args = $self->_arg_list( @rest );
 
-   $self->throw( 'No key specified' ) unless (my $key = $args->{k});
+   my $key = $args->{k} or $self->throw( 'No key specified' );
 
    return $self->_reset( q().$key );
 }
@@ -95,11 +94,8 @@ sub reset {
 sub set {
    my ($self, @rest) = @_; my $args = $self->_arg_list( @rest );
 
-   $self->throw( 'No key specified' ) unless (my $key = $args->{k});
-
-   my $pid = $args->{p} || $self->pid;
-
-   $self->throw( 'No pid specified' ) unless ($pid);
+   my $key = $args->{k} or $self->throw( 'No key specified' );
+   my $pid = $args->{p} || $self->pid or $self->throw( 'No pid specified' );
 
    return $self->_set( q().$key, $pid, $args->{t} || $self->time_out );
 }
@@ -120,11 +116,9 @@ sub timeout_error {
 # Private methods
 
 sub _arg_list {
-   my ($self, @rest) = @_;
+   my ($self, @rest) = @_; $rest[ 0 ] or return {};
 
-   return {} unless ($rest[0]);
-
-   return ref $rest[0] ? $rest[0] : { @rest };
+   return ref $rest[ 0 ] ? $rest[ 0 ] : { @rest };
 }
 
 sub _ensure_class_loaded {
@@ -132,12 +126,12 @@ sub _ensure_class_loaded {
 
    my $package_defined = sub { Class::MOP::is_class_loaded( $class ) };
 
-   return 1 if (not $opts->{ignore_loaded} and $package_defined->());
+   not $opts->{ignore_loaded} and $package_defined->() and return 1;
 
-   try        { Class::MOP::load_class( $class ) }
-   catch ($e) { $self->throw( $e ) }
+   try   { Class::MOP::load_class( $class ) }
+   catch { $self->throw( $_ ) };
 
-   return 1 if ($package_defined->());
+   $package_defined->() and return 1;
 
    my $e = 'Class [_1] loaded but package undefined';
 
@@ -145,10 +139,6 @@ sub _ensure_class_loaded {
    return; # Never reached
 }
 
-sub _hash_merge {
-   my ($self, $l, $r) = @_; return { %{ $l }, %{ $r || {} } };
-}
-
 sub _init {
    return;
 }
@@ -177,6 +167,12 @@ sub _set {
    return;
 }
 
+# Private subroutines
+
+sub __hash_merge {
+   return { %{ $_[ 0 ] }, %{ $_[ 1 ] || {} } };
+}
+
 1;
 
 __END__
@@ -189,7 +185,7 @@ IPC::SRLock - Set/reset locking semantics to single thread processes
 
 =head1 Version
 
-0.4.$Revision: 147 $
+0.5.$Revision: 150 $
 
 =head1 Synopsis
 
@@ -329,9 +325,9 @@ parameters
 
 Require the requested class, throw an error if it doesn't load
 
-=head2 _hash_merge
+=head2 __hash_merge
 
-   my $hash = $self->_hash_merge( { key1 => val1 }, { key2 => val2 } );
+   my $hash = __hash_merge( { key1 => val1 }, { key2 => val2 } );
 
 Simplistic merging of two hashes
 
